{% load static %}<!doctype html><html lang="en"><head><meta charset="utf-8"/><link rel="shortcut icon" href="{% static '/budgetmanager/img/favicon.ico' %}"/><link rel="manifest" href="/budgetmanager/manifest.webmanifest"/><meta name="viewport" content="initial-scale=1,width=device-width"/><title>Budget Manager</title><script type="module" crossorigin src="{% static 'budgetmanager/js/index-e8f94746.js' %}"></script><script id="vite-plugin-pwa:inline-sw">if('serviceWorker' in navigator) {window.addEventListener('load', () => {navigator.serviceWorker.register('/budgetmanager/service-worker.js', { scope: '/budgetmanager/' })})}</script></head><body><noscript>You need to enable JavaScript to run this app.</noscript><div id="root"></div></body></html>