# Generated by Django 5.0.2 on 2024-07-19 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budgetmanager', '0003_sharecode'),
    ]

    operations = [
        migrations.AddField(
            model_name='budget',
            name='last_used',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='payee',
            name='last_used',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
